is_leap_year: Is value a leap year?
Description
Determine whether an input value is a leap year using the branchless approach
of jerichaux (2025). Method provided for both Dates and numeric values.
Numeric values first floored before the calculation is made.
Usage
is_leap_year(x)is_leap(x)